"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initGlobal = void 0;
const chalk_1 = require("chalk");
const find_workspace_root_1 = require("./find-workspace-root");
const output_1 = require("./output");
/**
 * Nx is being run from outside a workspace
 */
function initGlobal() {
    const workspace = find_workspace_root_1.findWorkspaceRoot(process.cwd());
    if (workspace) {
        // Found a workspace root - hand off to the local copy of Nx
        try {
            const localNx = require.resolve('@nrwl/cli/bin/nx.js', {
                paths: [workspace.dir],
            });
            require(localNx);
        }
        catch (e) {
            output_1.output.error({
                title: `Could not find @nrwl/cli module in this workspace.`,
                bodyLines: [`Have you run ${chalk_1.default.bold.white(`npm/yarn install`)}?`],
            });
            process.exit(1);
        }
    }
    else {
        output_1.output.log({
            title: `The current directory isn't part of an Nx workspace.`,
            bodyLines: [
                `To create a workspace run:`,
                chalk_1.default.bold.white(`npx create-nx-workspace@latest <workspace name>`),
            ],
        });
        output_1.output.note({
            title: `For more information please visit https://nx.dev/`,
        });
        process.exit(1);
    }
}
exports.initGlobal = initGlobal;
//# sourceMappingURL=init-global.js.map